class CzException(Exception):
    ...


class AnswerRequiredError(CzException):
    ...
